[Asterisk-code-review] spelling: occurred (asterisk[master])

Josh Soref asteriskteam at digium.com
Sun Nov 7 00:13:09 CDT 2021


Josh Soref has uploaded this change for review. ( https://gerrit.asterisk.org/c/asterisk/+/17060 )


Change subject: spelling: occurred
......................................................................

spelling: occurred

Change-Id: I2db6eddea6d11322e1e2c94db1045557be79f87e
---
M apps/app_meetme.c
M channels/chan_dahdi.c
M channels/chan_unistim.c
M channels/sig_analog.c
M funcs/func_strings.c
M include/asterisk/config.h
M include/asterisk/fskmodem_float.h
M include/asterisk/fskmodem_int.h
M include/asterisk/json.h
M include/asterisk/test.h
M res/res_config_ldap.c
M res/res_fax.c
M res/res_phoneprov.c
13 files changed, 15 insertions(+), 15 deletions(-)



  git pull ssh://gerrit.asterisk.org:29418/asterisk refs/changes/60/17060/1

diff --git a/apps/app_meetme.c b/apps/app_meetme.c
index ebf69e0..0a78e4e 100644
--- a/apps/app_meetme.c
+++ b/apps/app_meetme.c
@@ -5722,7 +5722,7 @@
 		if (f->frametype == AST_FRAME_VOICE) {
 			ast_mutex_lock(&cnf->listenlock);
 			for (x = 0; x < AST_FRAME_BITS; x++) {
-				/* Free any translations that have occured */
+				/* Free any translations that have occurred */
 				if (cnf->transframe[x]) {
 					ast_frfree(cnf->transframe[x]);
 					cnf->transframe[x] = NULL;
diff --git a/channels/chan_unistim.c b/channels/chan_unistim.c
index 321cb63..ef672fe 100644
--- a/channels/chan_unistim.c
+++ b/channels/chan_unistim.c
@@ -459,7 +459,7 @@
 	ast_mutex_t lock;
 	struct sockaddr_in sin;	 /*!< IP address of the phone */
 	struct sockaddr_in sout;	/*!< IP address of server */
-	int timeout;			    /*!< time-out in ticks : resend packet if no ack was received before the timeout occured */
+	int timeout;			    /*!< time-out in ticks : resend packet if no ack was received before the timeout occurred */
 	unsigned short seq_phone;       /*!< sequence number for the next packet (when we receive a request) */
 	unsigned short seq_server;      /*!< sequence number for the next packet (when we send a request) */
 	unsigned short last_seq_ack;    /*!< sequence number of the last ACK received */
diff --git a/channels/sig_analog.c b/channels/sig_analog.c
index cc09760..2a19be4 100644
--- a/channels/sig_analog.c
+++ b/channels/sig_analog.c
@@ -3586,7 +3586,7 @@
 		}
 
 		/* Added more log_debug information below to provide a better indication of what is going on */
-		ast_debug(1, "Polarity Reversal event occured - DEBUG 2: channel %d, state %u, pol= %d, aonp= %d, honp= %d, pdelay= %d, tv= %" PRIi64 "\n", p->channel, ast_channel_state(ast), p->polarity, p->answeronpolarityswitch, p->hanguponpolarityswitch, p->polarityonanswerdelay, ast_tvdiff_ms(ast_tvnow(), p->polaritydelaytv) );
+		ast_debug(1, "Polarity Reversal event occurred - DEBUG 2: channel %d, state %u, pol= %d, aonp= %d, honp= %d, pdelay= %d, tv= %" PRIi64 "\n", p->channel, ast_channel_state(ast), p->polarity, p->answeronpolarityswitch, p->hanguponpolarityswitch, p->polarityonanswerdelay, ast_tvdiff_ms(ast_tvnow(), p->polaritydelaytv) );
 		break;
 	default:
 		ast_debug(1, "Dunno what to do with event %d on channel %d\n", res, p->channel);
diff --git a/funcs/func_strings.c b/funcs/func_strings.c
index 28fe6e0..10e4300 100644
--- a/funcs/func_strings.c
+++ b/funcs/func_strings.c
@@ -77,7 +77,7 @@
 		<description>
 			<para>Search the variable named <replaceable>varname</replaceable> for the string <replaceable>value</replaceable>
 			delimited by <replaceable>delim</replaceable> and return a 1-based offset as to its location. If not found
-			or an error occured, return <literal>0</literal>.</para>
+			or an error occurred, return <literal>0</literal>.</para>
 			<para>The delimiter may be specified as a special or extended ASCII character, by encoding it.  The characters
 			<literal>\n</literal>, <literal>\r</literal>, and <literal>\t</literal> are all recognized as the newline,
 			carriage return, and tab characters, respectively.  Also, octal and hexadecimal specifications are recognized
diff --git a/include/asterisk/config.h b/include/asterisk/config.h
index f53116d..d6047a3 100644
--- a/include/asterisk/config.h
+++ b/include/asterisk/config.h
@@ -959,7 +959,7 @@
  * same name.
  *
  * \retval 0 if a variable was replaced in the list
- * \retval -1 if no replacement occured
+ * \retval -1 if no replacement occurred
  *
  * \note The variable name comparison is performed case-sensitively
  * \note If a variable is replaced, its memory is freed.
diff --git a/include/asterisk/fskmodem_float.h b/include/asterisk/fskmodem_float.h
index 3b350fb..614e7ed 100644
--- a/include/asterisk/fskmodem_float.h
+++ b/include/asterisk/fskmodem_float.h
@@ -64,7 +64,7 @@
    \return return value is as follows:
    \arg 0: Still looking for something...
    \arg 1: An output byte was received and stored in outbyte
-   \arg -1: An error occured in the transmission
+   \arg -1: An error occurred in the transmission
    He must be called with at least 80 bytes of buffer. */
 int fsk_serial(fsk_data *fskd, short *buffer, int *len, int *outbyte);
 
diff --git a/include/asterisk/fskmodem_int.h b/include/asterisk/fskmodem_int.h
index 6a4db8b..72402ed 100644
--- a/include/asterisk/fskmodem_int.h
+++ b/include/asterisk/fskmodem_int.h
@@ -73,7 +73,7 @@
    \return return value is as follows:
    \arg 0: Still looking for something...
    \arg 1: An output byte was received and stored in outbyte
-   \arg -1: An error occured in the transmission
+   \arg -1: An error occurred in the transmission
    This must be called with at least 80 bytes of buffer. */
 int fsk_serial(fsk_data *fskd, short *buffer, int *len, int *outbyte);
 int fskmodem_init(fsk_data *fskd);
diff --git a/include/asterisk/json.h b/include/asterisk/json.h
index 3f485d1..db33a6f 100644
--- a/include/asterisk/json.h
+++ b/include/asterisk/json.h
@@ -844,7 +844,7 @@
  * \since 12.0.0
  */
 struct ast_json_error {
-	/*! Line number error occured on */
+	/*! Line number error occurred on */
 	int line;
 	/*! Character (not byte, can be different for UTF-8) column on which the error occurred. */
 	int column;
diff --git a/include/asterisk/test.h b/include/asterisk/test.h
index 90e772c..9bd1a28 100644
--- a/include/asterisk/test.h
+++ b/include/asterisk/test.h
@@ -74,7 +74,7 @@
       .
       .
       if (fail) {                 \\ the following is just some example logic
-          ast_test_status_update(test, "an error occured because...");
+          ast_test_status_update(test, "an error occurred because...");
           res = AST_RESULT_FAIL;
       } else {
           res = AST_RESULT_PASS
diff --git a/res/res_config_ldap.c b/res/res_config_ldap.c
index 135bb05..5465c59 100644
--- a/res/res_config_ldap.c
+++ b/res/res_config_ldap.c
@@ -800,7 +800,7 @@
 }
 
 /*! \brief LDAP base function
- * \return a null terminated array of ast_variable (one per entry) or NULL if no entry is found or if an error occured
+ * \return a null terminated array of ast_variable (one per entry) or NULL if no entry is found or if an error occurred
  * caller should free the returned array and ast_variables
  * \param entries_count_ptr is a pointer to found entries count (can be NULL)
  * \param basedn is the base DN
diff --git a/res/res_fax.c b/res/res_fax.c
index 7d69fc2..2a08325 100644
--- a/res/res_fax.c
+++ b/res/res_fax.c
@@ -1158,7 +1158,7 @@
 
 	/* locate a FAX technology module that can handle said requirements
 	 * Note: the requirements have not yet been finalized as T.38
-	 * negotiation has not yet occured. */
+	 * negotiation has not yet occurred. */
 	AST_RWLIST_RDLOCK(&faxmodules);
 	AST_RWLIST_TRAVERSE(&faxmodules, faxmod, list) {
 		if ((faxmod->tech->caps & details->caps) != details->caps) {
diff --git a/res/res_phoneprov.c b/res/res_phoneprov.c
index ad74ae0..c56da4a 100644
--- a/res/res_phoneprov.c
+++ b/res/res_phoneprov.c
@@ -996,7 +996,7 @@
 
 out500:
 	route = unref_route(route);
-	ast_http_error(ser, 500, "Internal Error", "An internal error has occured.");
+	ast_http_error(ser, 500, "Internal Error", "An internal error has occurred.");
 	return 0;
 }
 

diff --git a/channels/chan_dahdi.c b/channels/chan_dahdi.c
index b12beeb..75f53ad 100644
--- a/channels/chan_dahdi.c
+++ b/channels/chan_dahdi.c
@@ -8260,7 +8260,7 @@
 			(p->polarity == POLARITY_REV) &&
 			((ast_channel_state(ast) == AST_STATE_UP) || (ast_channel_state(ast) == AST_STATE_RING)) ) {
 			/* Added log_debug information below to provide a better indication of what is going on */
-			ast_debug(1, "Polarity Reversal event occured - DEBUG 1: channel %d, state %u, pol= %d, aonp= %d, honp= %d, pdelay= %d, tv= %" PRIi64 "\n", p->channel, ast_channel_state(ast), p->polarity, p->answeronpolarityswitch, p->hanguponpolarityswitch, p->polarityonanswerdelay, ast_tvdiff_ms(ast_tvnow(), p->polaritydelaytv) );
+			ast_debug(1, "Polarity Reversal event occurred - DEBUG 1: channel %d, state %u, pol= %d, aonp= %d, honp= %d, pdelay= %d, tv= %" PRIi64 "\n", p->channel, ast_channel_state(ast), p->polarity, p->answeronpolarityswitch, p->hanguponpolarityswitch, p->polarityonanswerdelay, ast_tvdiff_ms(ast_tvnow(), p->polaritydelaytv) );
 
 			if (ast_tvdiff_ms(ast_tvnow(), p->polaritydelaytv) > p->polarityonanswerdelay) {
 				ast_debug(1, "Polarity Reversal detected and now Hanging up on channel %d\n", p->channel);
@@ -8274,7 +8274,7 @@
 			ast_debug(1, "Ignoring Polarity switch to IDLE on channel %d, state %u\n", p->channel, ast_channel_state(ast));
 		}
 		/* Added more log_debug information below to provide a better indication of what is going on */
-		ast_debug(1, "Polarity Reversal event occured - DEBUG 2: channel %d, state %u, pol= %d, aonp= %d, honp= %d, pdelay= %d, tv= %" PRIi64 "\n", p->channel, ast_channel_state(ast), p->polarity, p->answeronpolarityswitch, p->hanguponpolarityswitch, p->polarityonanswerdelay, ast_tvdiff_ms(ast_tvnow(), p->polaritydelaytv) );
+		ast_debug(1, "Polarity Reversal event occurred - DEBUG 2: channel %d, state %u, pol= %d, aonp= %d, honp= %d, pdelay= %d, tv= %" PRIi64 "\n", p->channel, ast_channel_state(ast), p->polarity, p->answeronpolarityswitch, p->hanguponpolarityswitch, p->polarityonanswerdelay, ast_tvdiff_ms(ast_tvnow(), p->polaritydelaytv) );
 		break;
 	default:
 		ast_debug(1, "Dunno what to do with event %d on channel %d\n", res, p->channel);
@@ -8439,7 +8439,7 @@
 		/*
 		 * Check to see if the channel is still associated with the same
 		 * private structure.  While the Asterisk channel was unlocked
 		 * the following events may have occured:
 		 *
 		 * 1) A masquerade may have associated the channel with another
 		 * technology or private structure.
@@ -8439,7 +8439,7 @@
 		 * Check to see if the channel is still associated with the same
 		 * private structure.  While the Asterisk channel was unlocked
-		 * the following events may have occured:
+		 * the following events may have occurred:
 		 *
 		 * 1) A masquerade may have associated the channel with another
-- 
To view, visit https://gerrit.asterisk.org/c/asterisk/+/17060
To unsubscribe, or for help writing mail filters, visit https://gerrit.asterisk.org/settings

Gerrit-Project: asterisk
Gerrit-Branch: master
Gerrit-Change-Id: I2db6eddea6d11322e1e2c94db1045557be79f87e
Gerrit-Change-Number: 17060
Gerrit-PatchSet: 1
Gerrit-Owner: Josh Soref <jsoref at gmail.com>
Gerrit-CC: Friendly Automation
Gerrit-MessageType: newchange
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.digium.com/pipermail/asterisk-code-review/attachments/20211107/2709fdfb/attachment-0001.html>


More information about the asterisk-code-review mailing list